import string
stopwordsarr = [
        'a', 'aa', 'aaa', 'aaah', 'aah', 'abe', 'abes', 'abo', 'abosa', 'abu', 'acaba', 'acayip', 'accelerando', 'acele',
        'aceleten', 'acep', 'acımasız', 'acımasızcasına', 'acilen', 'âciz', 'âcizane', 'aç', 'açık', 'açıkçası', 'açıktan',
        'adamakıllı', 'adamcasına', 'adedî', 'âdeta', 'adına', 'adilane', 'afedersin', 'afedersinin', 'aferin',
        'affettuoso', 'agitato', 'agucuk', 'ağababa', 'ağabey', 'ağır', 'ağızdan', 'ah', 'aha', 'ahacık', 'ahbap', 'aheste',
        'ahir', 'ahiren', 'ahlaken', 'ailecek', 'ait', 'akabinde', 'akıbet', 'akilane', 'aklen', 'aklınca', 'aksine',
        'akşamdan', 'akşamları', 'akşamleyin', 'akşamüstü', 'akşamüzeri', 'alabildiğine', 'alarga', 'alelacele',
        'alelhesap', 'alelhusus', 'alelıtlak', 'alelumum', 'alelusul', 'âlem', 'alenen', 'alessabah', 'aleykümselâm',
        'alicenap', 'alimallah', 'âlimane', 'allahtan', 'allegretto', 'allegro', 'alo', 'altı', 'altıncı', 'altışar',
        'altmış', 'ama', 'amabile', 'aman', 'amanın', 'amca', 'amenna', 'âmin', 'amirane', 'amma', 'ana', 'anafordan',
        'anal', 'anasıl', 'anbean', 'anca', 'ancak', 'andante', 'andantino', 'anında', 'ani', 'aniden', 'anif', 'animato',
        'anlaşılan', 'ansızın', 'antrparantez', 'apaçık', 'apak', 'apansız', 'apansızın', 'apartopar', 'aport',
        'appassionato', 'aptal', 'aptalcasına', 'aracılığıyla', 'aralıkta', 'arasıra', 'ardarda', 'ardınca', 'ardından',
        'arifane', 'ariyeten', 'arkadan', 'arkadaşça', 'arkaüstü', 'arş', 'artık', 'asabi', 'asaleten', 'asıl', 'asla',
        'aslen', 'aslında', 'aşağı', 'âşık', 'âşıkane', 'aşırı', 'aşikâre', 'aşkın', 'atbaşı', 'atfen', 'atmış', 'atmışar',
        'atmışıncı', 'avantadan', 'avara', 'ay', 'ayakta', 'ayaküstü', 'ayaküzeri', 'aybeay', 'ayı', 'ayık', 'aylarca',
        'aylık', 'aynen', 'aynıyla', 'ayol', 'ayrı', 'ayrıca', 'ayrıyeten', 'az', 'azade', 'azıcık', 'azimkârane', 'bacı',
        'badehu', 'badema', 'bahar', 'bahusus', 'bakarak', 'bakımından', 'bakındı', 'balıklama', 'balıksırtı', 'banko',
        'bari', 'basbayağı', 'basmakalıp', 'başbaşa', 'başıboş', 'başka', 'başkası', 'başlıbaşına', 'başta', 'baştan',
        'baştanbaşa', 'başüstüne', 'batsat', 'bayağı', 'bayan', 'baygın', 'bayramüstü', 'bayramüzeri', 'bazan', 'bazen',
        'bazı', 'bazısı', 'be', 'bebek', 'bebekçe', 'bedaheten', 'bedava', 'bedavadan', 'bedavasına', 'bedavaya', 'bedenen',
        'begayet', 'behemehâl', 'behey', 'beleşten', 'beli', 'belirgin', 'belki', 'bembeyaz', 'ben', 'bence', 'bencileyin',
        'benimki', 'beraber', 'beraberce', 'berabere', 'beraberinde', 'bereket', 'berenarı', 'beri', 'beriki', 'bermutat',
        'bertafsil', 'bertaraf', 'besbelli', 'besmelesiz', 'beş', 'beşer', 'beşinci', 'beşyüz', 'beybaba', 'beyhude',
        'beyninde', 'bezgin', 'bıldır', 'biçimli', 'bihaber', 'bihakkın', 'biilaç', 'bikes', 'bilahare', 'bilaistisna',
        'bilakis', 'bilasebep', 'bilavasıta', 'bilcümle', 'bile', 'bilerek', 'bilfarz', 'bilfiil', 'bilhassa', 'bililtizam',
        'bilistifade', 'billahi', 'bilmukabele', 'bilmünasebe', 'bilvasıta', 'bin', 'binaen', 'binaenaleyh', 'biner',
        'bininci', 'binnetice', 'binyıl', 'bip', 'biperva', 'bir', 'birader', 'birara', 'birarada', 'biraz', 'birazcık',
        'birazdan', 'birbiri', 'birçoğu', 'birçok', 'birden', 'birdenbire', 'birer', 'birgün', 'biri', 'birileri',
        'birinci', 'birkaç', 'birkaçı', 'birlikte', 'birtakım', 'bis', 'bismillâh', 'bitevi', 'biteviye', 'bittabi', 'biz',
        'bizar', 'bizatihi', 'bizce', 'bizcileyin', 'bizimki', 'bizzat', 'bodoslama', 'bodoslamadan', 'bolca', 'bonjur',
        'boş', 'boşuna', 'boyca', 'boylamasına', 'boyuna', 'boyunca', 'bönce', 'böyle', 'böylece', 'böylecene',
        'böylelikle', 'böylesi', 'böylesine', 'bravo', 'bre', 'bu', 'budalacasına', 'bugün', 'bugünden', 'bugünlük',
        'bulanık', 'bunca', 'bunlar', 'buracıkta', 'burada', 'buradan', 'bünyece', 'büsbütün', 'bütünüyle', 'caba',
        'cabadan', 'cahilane', 'cana', 'candan', 'canıgönülden', 'canıyürekten', 'caniyane', 'canlı', 'cansiparane',
        'capcanlı', 'carcar', 'carcur', 'cartadak', 'cartadan', 'cebren', 'ceffelkalem', 'ceman', 'cesur', 'cesurane',
        'cetbecet', 'cevaben', 'cık', 'cılız', 'cıs', 'cicoz', 'cidden', 'ciddi', 'cihangirane', 'cihetiyle', 'cismen',
        'cuk', 'cumbadak', 'cumburlop', 'cumhurca', 'cuppadak', 'cümle', 'cümlesi', 'cümleten', 'çabucacık', 'çabucak',
        'çabuk', 'çakırkeyif', 'çaktırmadan', 'çalak', 'çalakalem', 'çalakamçı', 'çalakaşık', 'çalakılıç', 'çalakürek',
        'çalyaka', 'çap', 'çapkın', 'çapraz', 'çaprazlama', 'çaprazlamasına', 'çaprazvari', 'çarçabuk', 'çarnaçar',
        'çarpık', 'çekinik', 'çengüçağanak', 'çepçevre', 'çepeçevre', 'çeyrek', 'çıldırasıya', 'çılgıncasına', 'çınsabah',
        'çırılçıplak', 'çinko', 'çocukça', 'çocuksu', 'çoğu', 'çoğun', 'çoğunlukla', 'çok', 'çokbilmiş', 'çokça', 'çokları',
        'çokluk', 'çoklukla', 'çoktandır', 'çöğunlukla', 'çökkün', 'çünki', 'çünkü', 'çüş', 'da', 'dadaş', 'dah', 'daha',
        'dahası', 'dahi', 'dâhice', 'dâhil', 'dâhilen', 'dâhiyane', 'daim', 'daima', 'dair', 'dakika', 'dakikalarca',
        'dakikasında', 'dalgın', 'dalgınlıkla', 'dalgündüz', 'dalkavukça', 'dalkılıç', 'dalöğle', 'dalya', 'damsız',
        'dandini', 'dangadak', 'dangalakça', 'dar', 'davetsiz', 'dayalı', 'dayı', 'de', 'dede', 'defaatle', 'defalarca',
        'defaten', 'değil', 'değin', 'deh', 'dehşet', 'dehşetli', 'dek', 'dekreşendo', 'delice', 'delicesine', 'delikanlı',
        'dembedem', 'demek', 'demin', 'demincek', 'denli', 'derakap', 'derece', 'derhâl', 'derinden', 'derinlemesine',
        'derinliğine', 'derken', 'dervişane', 'destur', 'destursuz', 'desturun', 'devam', 'devre', 'devren', 'deyyus',
        'dışarı', 'diğeri', 'dikey', 'dikine', 'dikkat', 'dikkatli', 'diklemesine', 'dimdik', 'diminuendo', 'dince', 'dinç',
        'dinen', 'direkt', 'diye', 'doğaçlama', 'doğaçtan', 'doğallıkla', 'doğru', 'doğrudan', 'doğrusu', 'doğuştan',
        'doksan', 'doksanar', 'doksanıncı', 'dokuz', 'dokuzar', 'dokuzuncu', 'dolayı', 'dolayısıyla', 'doludizgin',
        'domuzuna', 'dosdoğru', 'dostane', 'doyasıya', 'dörder', 'dördüncü', 'dört', 'dörtnala', 'durmadan', 'duyguca',
        'dün', 'dünden', 'dünyada', 'düpedüz', 'dürzü', 'düt', 'düzgün', 'e', 'ebediyen', 'edepli', 'edepsizcesine',
        'edibane', 'efece', 'efendi', 'efendim', 'efsus', 'eğer', 'eğreti', 'eğri', 'eh', 'ekseri', 'ekseriya',
        'ekseriyetle', 'ekstra', 'elaman', 'elan', 'elbet', 'elbette', 'elden', 'elektriksiz', 'elele', 'elhak',
        'elhamdülillah', 'elhasıl', 'eliyle', 'elli', 'ellinci', 'ellişer', 'elveda', 'emaneten', 'emprovize', 'en',
        'enayicesine', 'ençok', 'ender', 'enikonu', 'enlemesine', 'epey', 'epeyce', 'epeydir', 'epeyi', 'epeyice', 'er',
        'erden', 'ergeç', 'erken', 'erkence', 'erkenden', 'esasen', 'eskaza', 'eskiden', 'esnasında', 'estağfurullah',
        'eşekçe', 'eşkin', 'etraflı', 'etraflıca', 'evce', 'evcek', 'evelallah', 'evet', 'evvel', 'evvela', 'evvelce',
        'evvelden', 'evvelemirde', 'evvelleri', 'ey', 'eyvah', 'ezberden', 'ezbere', 'ezcümle', 'ezercesine', 'ezik',
        'ezkaza', 'fakat', 'falan', 'falanca', 'faraza', 'farzımahal', 'farzımuhal', 'fasih', 'fatihane', 'fayrap', 'fazla',
        'fazladan', 'fazlasıyla', 'fena', 'fertik', 'fesuphanallah', 'fır', 'fırdolayı', 'fıstıki', 'fıtraten', 'fiilen',
        'fikren', 'filan', 'filhakika', 'filvaki', 'fonda', 'fondip', 'fora', 'forte', 'fortepiano', 'fortissimo',
        'fücceten', 'gafilane', 'gâh', 'gâhi', 'galiba', 'garanti', 'garip', 'gâvurcasına', 'gayet', 'gayetle', 'gayrı',
        'gayri', 'gece', 'geceleri', 'geceleyin', 'geç', 'geçe', 'geçende', 'geçenlerde', 'gelgelelim', 'gelişigüzel',
        'gene', 'genelde', 'genellikle', 'gepgenç', 'gerçekte', 'gerçekten', 'gerçi', 'gereğince', 'gerek', 'gerekse',
        'geri', 'gerisingeri', 'gerisingeriye', 'gevşek', 'gırla', 'gıyaben', 'gıyabında', 'gibi', 'gibilerden',
        'gibisinden', 'giderayak', 'giderek', 'gidi', 'gine', 'gitgide', 'gittikçe', 'gizli', 'gönlünce', 'göre',
        'görünürde', 'görünürlerde', 'görünüşte', 'götürü', 'gücün', 'güç', 'güçbela', 'güçlükle', 'gümbedek', 'günaşırı',
        'günaydın', 'günbegün', 'günde', 'gündüz', 'gündüzleri', 'gündüzleyin', 'gündüzün', 'günlerce', 'günübirliğine',
        'günübirlik', 'güpegündüz', 'gürpedek', 'güya', 'güzel', 'güzelim', 'güzellikle', 'güzün', 'ha', 'haa', 'habire',
        'hacmen', 'haddizatında', 'hadi', 'hadisene', 'hafazanallah', 'hafif', 'hafiften', 'hafta', 'haftalarca', 'hah',
        'hain', 'haincesine', 'hakeza', 'hakikat', 'hakikaten', 'hakimane', 'hâkimane', 'hakkında', 'hakkıyla', 'hâlâ',
        'hâlbuki', 'hâlen', 'hâlihazırda', 'halisane', 'hâliyle', 'hamdolsun', 'hamilen', 'handiyse', 'hangi', 'hangisi',
        'hanımanne', 'hani', 'hapur', 'harfiyen', 'haricen', 'hariç', 'harika', 'harrangürra', 'hart', 'hartadak',
        'hasbelkader', 'hasebiyle', 'hasmane', 'hassaten', 'haşa', 'hâşâ', 'haşin', 'hatta', 'havadan', 'hay', 'hayalen',
        'haybeden', 'hayda', 'haydi', 'haydin', 'haydindi', 'haydisene', 'hayfa', 'hayhay', 'hayıf', 'hayır', 'hayli',
        'hayret', 'hayretle', 'hayrola', 'haysiyetiyle', 'haza', 'hazır', 'hazret', 'he', 'helalinden', 'hele', 'hem',
        'hemen', 'hemencecik', 'henüz', 'hep', 'hepsi', 'hepten', 'her', 'herbiri', 'herhâlde', 'herkes', 'herzaman', 'hey',
        'heyetiyle', 'heyhat', 'hımhım', 'hıncahınç', 'hınk', 'hızla', 'hızlı', 'hiç', 'hiçbir', 'hiçbiri', 'hiçten',
        'hilkaten', 'hiş', 'hişt', 'hitaben', 'Hm', 'Hmm', 'hodbehot', 'hop', 'hoppadak', 'hoppala', 'hoş', 'hoşçakal',
        'hoşt', 'hoyrat', 'höst', 'höt', 'hu', 'hukuken', 'hurra', 'husumetkâr', 'hususuyla', 'hücum', 'hükmen', 'hülasa',
        'hülasaten', 'hür', 'hürmeten', 'hürmetkârane', 'hürya', 'ıh', 'ıssız', 'ibne', 'icabında', 'içeri', 'için',
        'içinde', 'içre', 'içten', 'içtenlikle', 'idareten', 'iğrenç', 'ihtimal', 'ihtiyaten', 'iken', 'iki', 'ikinci',
        'ikindi', 'ikindileri', 'ikindiüstü', 'ikindiüzeri', 'ikindiyin', 'ikişer', 'iktisaden', 'ilâ', 'İlahî', 'ilânen',
        'ilanihaye', 'ilâveten', 'ile', 'ilelebet', 'ileri', 'ileride', 'ilişkin', 'ilk', 'ilkbahar', 'ilkin', 'ilkönce',
        'ilkten', 'illâ', 'illâki', 'illâllah', 'ille', 'imdat', 'imdi', 'inadına', 'incecikten', 'indinde', 'insaf',
        'inşallah', 'iptida', 'iptidaları', 'irsen', 'irticalen', 'isabet', 'ise', 'ismen', 'isnaden', 'ister', 'istinaden',
        'işte', 'iştiraken', 'ithafen', 'itibaren', 'itibarıyla', 'itoğluit', 'ivedi', 'ivedilikle', 'iyi', 'iyicene',
        'iyilikle', 'izafeten', 'kabaca', 'kabala', 'kablelmilat', 'kaç', 'kaçak', 'kaçta', 'kadar', 'kafadan', 'kâffesi',
        'kâfi', 'kâfir', 'kâh', 'kahrolsun', 'kâinat', 'kala', 'kalben', 'kalender', 'kamera', 'kâmilen', 'kanalıyla',
        'kanunen', 'kânunen', 'kapkara', 'kararlamadan', 'kardeş', 'kargatulumba', 'karşı', 'karşıllıklı', 'karşın',
        'kaskatı', 'kasten', 'katbekat', 'kategorik', 'katı', 'katiyen', 'katiyetle', 'katrilyon', 'katrilyonar',
        'katrilyonuncu', 'kavi', 'kazaen', 'kazara', 'kefaleten', 'kemakân', 'kendi', 'kendiliğimizden', 'kendiliğinden',
        'kendiliğinizden', 'kendiliklerinden', 'kendince', 'kendinden', 'kendisince', 'kentilyon', 'kerhen', 'kesin',
        'kesinkes', 'kesinlikle', 'kesmece', 'kestirmeden', 'keşke', 'keşki', 'keyfince', 'keza', 'kıçüstü', 'kılıcına',
        'kırgın', 'kırk', 'kırkar', 'kırkıncı', 'kırkyıl', 'kısa', 'kısacası', 'kıskıvrak', 'kısmen', 'kısmet', 'kış',
        'kışın', 'kıtlama', 'kıyasen', 'kıyasıya', 'kız', 'ki', 'kim', 'kimi', 'kimileyin', 'kimisi', 'kimse', 'kolay',
        'kolaycacık', 'kolayda', 'kolaylıkla', 'kolektif', 'kolkola', 'koşa', 'koyu', 'köftehor', 'köpekoğlu', 'köpoğlu',
        'körcesine', 'körkütük', 'körlemeden', 'kötü', 'kudretten', 'kulaktan', 'kurban', 'kuvvetle', 'külhani', 'külliyen',
        'küskütük', 'küttedek', 'laakal', 'lacerem', 'laf', 'lafzen', 'lahavle', 'lahzada', 'lakayıt', 'lakin', 'lala',
        'lan', 'lanet', 'lappadak', 'larghetto', 'largo', 'larp', 'larpadak', 'laubaliyane', 'lava', 'layıkıyla', 'lebalep',
        'lebbeyk', 'legato', 'lento', 'levendane', 'loppadak', 'lüpten', 'lütfen', 'lütufkârane', 'maada', 'maaile',
        'maalesef', 'maalmemnuniye', 'maatteessüf', 'maazallah', 'maddeten', 'madem', 'mademki', 'maestoso', 'mağrurane',
        'mağrurcasına', 'mahcubane', 'mahcup', 'mahfuzen', 'mahiye', 'mahkûmane', 'mahsuben', 'mahsus', 'mahsusen',
        'mahzunane', 'malca', 'malen', 'malulen', 'malum', 'mamafih', 'manen', 'mantıken', 'manyak', 'marifetiyle', 'marş',
        'masumane', 'maşallah', 'mayna', 'mealen', 'mebni', 'mecazen', 'mecburen', 'meccanen', 'mecnunane', 'medet',
        'meğer', 'meğerki', 'meğerse', 'melfufen', 'melul', 'memnun', 'memnuniyetle', 'mepsuten', 'merdane', 'merhaba',
        'merhameten', 'mesabesinde', 'meselâ', 'mestane', 'mesudane', 'meşruten', 'metazori', 'mevkufen', 'mezzo', 'mı',
        'mi', 'milim', 'milyar', 'milyarar', 'milyarıncı', 'milyon', 'milyonar', 'milyonuncu', 'minnettarane', 'minnoş',
        'miskalle', 'miskinane', 'mizacen', 'monşer', 'moralman', 'motamot', 'mu', 'muahharen', 'muhakkak', 'muhtasaran',
        'muhtemelen', 'mukabil', 'mukaddema', 'muntazam', 'muntazaman', 'muslihane', 'mutlak', 'mutlaka', 'muttasıl',
        'muvacehesinde', 'muvakkaten', 'muzafferane', 'mü', 'mübarek', 'müdellel', 'müebbeden', 'müjde', 'mükâfaten',
        'mükemmel', 'mükemmelen', 'mükerreren', 'münasebetiyle', 'münferiden', 'münhasıran', 'müphem', 'müreffehen',
        'müstacelen', 'müstakilen', 'müstehzi', 'müstemirren', 'müsteniden', 'müstesna', 'müştereken', 'müteakiben',
        'müteakip', 'mütemadi', 'mütemadiyen', 'müteneffir', 'mütenekkiren', 'müteselsilen', 'müteveccihen', 'müthiş',
        'müttefikan', 'müttehiden', 'naçizane', 'nadir', 'nadiren', 'nafile', 'nagehan', 'nah', 'nakden', 'nakıs', 'naklen',
        'nakzen', 'namağlup', 'namına', 'namütenahi', 'nasıl', 'nasılsa', 'naşi', 'nazaran', 'nazarında', 'nazikâne',
        'nazmen', 'ne', 'neden', 'nedeniyle', 'nedense', 'nere', 'nerede', 'nereden', 'neredeyse', 'neresi', 'nereye',
        'nesi', 'neşren', 'neticeten', 'nevmit', 'neyleyim', 'neyse', 'nezaketen', 'nezdinde', 'nice', 'niçin', 'nihayet',
        'nihayetinde', 'nine', 'ninni', 'nispet', 'nispeten', 'nispetle', 'nite', 'nitekim', 'niye', 'nöbetleşe', 'numerik',
        'o', 'oburcasına', 'of', 'oğul', 'oh', 'oha', 'olamaz', 'olasıya', 'oldu', 'oldukça', 'ole', 'oley', 'on', 'onaltı',
        'onaltıncı', 'onar', 'onbeş', 'onbeşinci', 'onca', 'onculayın', 'ondördüncü', 'ondört', 'onlar', 'onlarca',
        'onuncu', 'onüç', 'onüçüncü', 'oo', 'oof', 'ooo', 'oracıkta', 'orada', 'oradan', 'oral', 'oraya', 'orsa', 'ortada',
        'ortaklaşa', 'ortalamasına', 'ortalıkta', 'Osmanlıca', 'otomatikman', 'otuz', 'otuzar', 'otuzuncu', 'oy', 'oysa',
        'oysaki', 'öbür', 'öbürkü', 'öbürü', 'öf', 'öğleleri', 'öğlende', 'öğlenleri', 'öğlenleyin', 'öğleüstü',
        'öğleüzeri', 'öğleyin', 'öhö', 'öldüresiye', 'ölesiye', 'ölüm', 'ölümüne', 'ömrübillâh', 'önce', 'önceden',
        'önceleri', 'öncelikle', 'önünden', 'ööf', 'örneğin', 'öte', 'öteki', 'ötekisi', 'ötürü', 'öyle', 'öylelikle',
        'öylemesine', 'öylesi', 'öylesine', 'öz', 'özcesi', 'özellikle', 'palaspandıras', 'paraca', 'pas', 'patadak',
        'pattadak', 'pattadan', 'paydos', 'pederane', 'pehlivanane', 'pehpeh', 'pek', 'pekâlâ', 'peki', 'pekiyi', 'peltek',
        'perhizkâr', 'pes', 'peşin', 'peşinen', 'peyapey', 'peyderpey', 'peygamberane', 'peygambervari', 'pezevenk', 'pırt',
        'pir', 'pist', 'piyano', 'pöf', 'pöh', 'pratikte', 'presto', 'psikolojikman', 'puf', 'puşt', 'pürdikkat', 'Rabbena',
        'raddelerinde', 'rağmen', 'rahat', 'rahatçana', 'rahatlıkla', 'rahîm', 'rahvan', 'rappadak', 'rapten', 'rastgele',
        'resen', 'resmen', 'retrospektif', 'rindane', 'riyakârane', 'riyasız', 'ruhen', 'ruzuşeb', 'saadetle', 'saatlerce',
        'sabah', 'sabaha', 'sabahları', 'sabahleyin', 'sabahtan', 'sabırla', 'sade', 'sadece', 'sadıkane', 'safçasına',
        'safi', 'safiyane', 'sağlam', 'sağlıcakla', 'sağlığınıza', 'sahi', 'sahiden', 'sakın', 'salimen', 'salise',
        'salisen', 'sallapati', 'salt', 'samimi', 'samimiyetle', 'sanatkârane', 'saniye', 'sanki', 'sapasağlam',
        'sarahaten', 'sargın', 'sarhoş', 'sarmaşdolaş', 'sayesinde', 'sayıca', 'sebebiyle', 'sefihane', 'sefil', 'sefilane',
        'sehven', 'sek', 'sekiz', 'sekizer', 'sekizinci', 'seksen', 'seksener', 'sekseninci', 'selâmünaleyküm', 'sen',
        'seneye', 'serapa', 'serbest', 'sereserpe', 'seri', 'serian', 'serinkanlı', 'sermestane', 'sersefil', 'sert',
        'sesli', 'sessiz', 'seyrek', 'seyyanen', 'sıfır', 'sıfırar', 'sıfırıncı', 'sık', 'sıkça', 'sıkı', 'sımsıcak',
        'sımsıkı', 'sınırsız', 'sırasında', 'sırasıyla', 'sırf', 'sırtüstü', 'sıvırya', 'siftah', 'silik', 'silme',
        'sittinsene', 'siyaseten', 'siz', 'soğuk', 'sokulu', 'son', 'sonbahar', 'sonra', 'sonradan', 'sonraları', 'sonunda',
        'sözde', 'sözgelimi', 'sözgelişi', 'spontane', 'suçüstü', 'sularında', 'suphanallah', 'sureta', 'suskun', 'suspus',
        'susuz', 'süratle', 'sürekli', 'sürgit', 'şahsen', 'şakacıktan', 'şakadan', 'şakkadak', 'şakkadanak', 'şakrak',
        'şapadanak', 'şappadak', 'şarkadak', 'şaşı', 'şayet', 'şeklen', 'şeran', 'şımarık', 'şıppadak', 'şırakkadak',
        'şifahen', 'şimdi', 'şimdiden', 'şimdilerde', 'şimdileyin', 'şimdilik', 'şinanay', 'şipşak', 'şorolop', 'şöyle',
        'şöylesine', 'şu', 'şunlar', 'şuracıkta', 'şurada', 'şüphesiz', 'ta', 'taammüden', 'taban', 'tabanvay', 'tabi',
        'tabiatıyla', 'tabiî', 'tahminen', 'tahriren', 'takdirde', 'takiben', 'takkadak', 'takriben', 'tallahi', 'tam',
        'tamam', 'tamamen', 'tamamıyla', 'tamamiyle', 'taptaze', 'tarafından', 'tarihen', 'tastamam', 'tatlı', 'tatlılıkla',
        'tatsız', 'teberrüken', 'tedbiren', 'tedricen', 'tedviren', 'tek', 'tekdüze', 'tekiden', 'tekmil', 'tekrar',
        'tekraren', 'telmihen', 'temiz', 'temsilen', 'tepetakla', 'tepetaklak', 'tepeüstü', 'terbiyesizcesine', 'tercihan',
        'tercihen', 'tersine', 'terütaze', 'tesadüfen', 'tesadüfi', 'teslim', 'tevfikan', 'teyze', 'tez', 'tezelden',
        'tıbben', 'tıkabasa', 'tıngadak', 'tıpatıp', 'tıpkı', 'top', 'toptan', 'topu', 'topyekûn', 'tös', 'töskürü',
        'transit', 'trilyon', 'trilyonar', 'trilyonuncu', 'tu', 'tuh', 'tuhaf', 'tutturabildiğine', 'tuu', 'tuuu', 'tü',
        'tüh', 'tükenik', 'tüm', 'tümden', 'tümü', 'tümüyle', 'tünaydın', 'Türkçesi', 'tüü', 'tüüü', 'ucuzuna', 'uf',
        'ufaklık', 'uğrun', 'uğrunda', 'ulan', 'uluorta', 'umum', 'umumiyetle', 'upuzun', 'usangın', 'uslu', 'ustalıkla',
        'usturuplu', 'usul', 'usulca', 'usulcacık', 'usuldan', 'usulen', 'usulünce', 'uyarınca', 'uysal', 'uz', 'uzadıya',
        'uzaktan', 'uzun', 'uzunlamasına', 'üç', 'üçer', 'üçüncü', 'üf', 'üstadane', 'üstat', 'üstelik', 'üstten', 'üstüne',
        'üstünkörü', 'üzere', 'üzerinde', 'üzerine', 'üzre', 'vah', 'vahşiyane', 'vaktinde', 'vaktiyle', 'vaktizamanında',
        'vallaha', 'vallahi', 'varda', 'vasıtasıyla', 'vay', 've', 'vehleten', 'vekâleten', 'velakin', 'velet', 'velev',
        'velhâsıl', 'velhâsılıkelâm', 'veresiye', 'verevine', 'vesselâm', 'veya', 'veyahut', 'vicahen', 'vicdanen', 'vira',
        'viya', 'voyvo', 'vurtut', 'ya', 'yaa', 'yaaa', 'yahey', 'yahu', 'yahut', 'yakın', 'yakında', 'yakından',
        'yakınlarda', 'yakinen', 'yalancıktan', 'yalandan', 'yalapşap', 'yalınayak', 'yallah', 'yalnız', 'yalnızca',
        'yamyassı', 'yan', 'yana', 'yanaşık', 'yanında', 'yanısıra', 'yani', 'yanlamasına', 'yanlış', 'yanlışlıkla',
        'yapayalnız', 'yapyakın', 'yaradılıştan', 'yarı', 'yarımşar', 'yarın', 'yaşa', 'yaşasın', 'yavaş', 'yavaşçacık',
        'yaya', 'yayan', 'yazık', 'yazın', 'yedi', 'yedinci', 'yedişer', 'yeğen', 'yekdiğeri', 'yekpare', 'yekten',
        'yekvücut', 'yenge', 'yengeçvari', 'yeni', 'yeniden', 'yenilerde', 'yepyeni', 'yerinde', 'yerine', 'yeterince',
        'yetmiş', 'yetmişer', 'yetmişinci', 'yevmiye', 'yıllarca', 'yıllığına', 'yısa', 'yine', 'yirmi', 'yirminci',
        'yirmişer', 'yo', 'yok', 'yoksa', 'yoluyla', 'yoo', 'yönelik', 'yuf', 'yuh', 'yuha', 'yukarı', 'yukarıdan',
        'yumuşakça', 'yürekten', 'yüz', 'yüzbeyüz', 'yüzbin', 'yüzbinlerce', 'yüzer', 'yüzgeri', 'yüzükoyun', 'yüzüncü',
        'yüzünden', 'yüzüstü', 'yüzyıl', 'yüzyüze', 'zahir', 'zahirde', 'zahiren', 'zalimane', 'zamanında', 'zararına',
        'zarfında', 'zarifane', 'zaten', 'zati', 'zecren', 'zımnen', 'zımnında', 'zıngadak', 'zıppadak', 'zihnen',
        'zilzurna', 'zinhar', 'zira', 'ziyadesiyle', 'zor', 'zoraki', 'zorla', 'zorlukla', 'dokuz', 'tamam', 'birisi',
        'bizi', 'i', 'bir', 'nun', 'kez', 'birşeyi', 'tüm', 'onlara', 'nerede', 'çünkü', 'ilgili', 'kendisine', 'buna',
        'senden', 'ettiğini', 'yapacak', 'böylece', 'edilmesi', 'fakat', 'yirmi', 'sizden', 'halde', 'dolayısıyla',
        'benden', 'şeyden', 'mi', 'bazıları', 'daha', 'hiçbir', 'lakin', 'hem', 'öte', 'herhangi', 'vardı', 'yaptığını',
        'şimdi', 'yaptığı', 'oluyor', 'rağmen', 'kimi', 'olsa', 'neyse', 'kim', 'olmak', 'katrilyon', 'öbür', 'biri',
        'olduğunu', 'yedi', 'yapıyor', 'elli', 'olduklarını', 'ne', 'beş', 'şayet', 'beni', 'için', 'tarafından', 'bile',
        'birkez', 'ediyor', 'onun', 'değil', 'olsun', 'ona', 'herkesi', 'sana', 'kendini', 'tam', 'nedenle', 'ye', 'kimin',
        'diğer', 'acaba', 'yi', 'otuz', 'içinde', 'hiçbiri', 'ı', 'zira', 'nasıl', 'bunu', 'kime', 'olan', 'nın', 'herkes',
        'olmayan', 'u', 'gereği', 'önce', 'var', 'da', 'yoksa', 'hala', 'asla', 'şunları', 'olup', 'dört', 'onlardan',
        'bazen', 'olur', 'doksan', 'yani', 'hep', 'tabii', 'onların', 'aslında', 'kendisini', 'karşın', 'kendine', 'ettiği',
        'en', 'bilhassa', 'olması', 'beyden', 'hangi', 'şeyler', 'olmaz', 'ondan', 'trilyon', 'her', 'belki', 'şeyi',
        'onları', 'tümü', 'diye', 'işte', 'gerek', 'dahi', 'çoğu', 'etmesi', 'veya', 'olmadığı', 'henüz', 'oysa', 'ederek',
        'bizden', 'olarak', 'yüz', 'ise', 'şöyle', 'yaptı', 'on', 'ediliyor', 'madem', 'iki', 'senin', 'artık', 'sadece',
        'üç', 'az', 'neden', 'benim', 'nün', 'oldu', 'sonra', 'üzere', 'seni', 'diğerleri', 'filan', 'bin', 'nin', 'ben',
        'sizin', 'ta', 'e', 'ile', 'niçin', 'itibariyle', 'sekiz', 'gibi', 'bütün', 'kimisi', 'yerine', 'dolayı', 'mu',
        'olursa', 'ön', 'milyon', 'dan', 'milyar', 'olduğu', 'yaptıkları', 'kadar', 'de', 'herkesin', 'bunların', 'ayrıca',
        'yapmak', 'hatta', 'yu', 'yine', 'göre', 'zaten', 'biz', 'öyle', 'kırk', 'gene', 'niye', 'bu', 'itibaren',
        'edilecek', 'kaç', 'un', 'arada', 'ün', 'orada', 'bunda', 'olmadı', 'birçoğu', 'mü', 'onlari', 'biraz', 'sanki',
        'nerde', 'birçok', 'bunlar', 'bizim', 'kendilerine', 'beri', 'ancak', 'ötürü', 'diğeri', 'çok', 'hiç', 'altmış',
        'ya', 'yapılan', 'onlar', 'falan', 'elbette', 'eğer', 'size', 'etti', 'defa', 'nereye', 'birkaç', 'altı', 'sen', 'o'
    ]
stopwordsarr = list(set(stopwordsarr))
def stopwords():
    return stopwordsarr
def stopwordsSpace():
    space=[]
    for i in stopwordsarr:
        i=" "+i+" "
        space.append(i)
    return space


#-*- coding: utf-8 -*-

from setuptools import setup, find_packages

with open('README.md', 'r') as f:
    LONG_DESCRIPTION = f.read()

setup(
    name= 'stopwords_tr',
    version='2.0.1',
    license='MIT',
    author="Metin Oktay DENIZ",
    author_email='metinoktaydenizz@gmail.com',
    description="Stopwords filter for Turkish languages",
    long_description=LONG_DESCRIPTION,
    long_description_content_type='text/markdown',
    url='https://github.com/metinoktayd/StopWords-Turkish-Language',
    include_package_data=True,
    keywords=['stopwords, language processing, nlp, filter, turkish stopwords, stopwords for tr, stop for tr, Türkçe Stopwords, Turkish stop, Türkçe Stop'],
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12'
    ],
    #py_modules=["stopwords_tr"]
    package_dir={'':'src'},
    packages= find_packages('src')
)
